@@ -43,6 +43,7 @@ from .constant import (
     MODEL_BABY,
     MODEL_ESSENTIAL,
     MODEL_ESSENTIAL_INDOOR,
+    MODEL_ESSENTIAL_XL,
     MODEL_PRO_2,
     MODEL_PRO_3,
     MODEL_PRO_3_FLOODLIGHT,
@@ -50,7 +51,9 @@ from .constant import (
     MODEL_PRO_5,
     MODEL_ULTRA,
     MODEL_WIRED_VIDEO_DOORBELL,
-    MODEL_WIREFREE_VIDEO_DOORBELL,
+    MODEL_WIRED_VIDEO_DOORBELL2_HD,
+    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+    MODEL_ESSENTIAL_VIDEO_DOORBELL,
     MODEL_GO,
     MOTION_DETECTED_KEY,
     MOTION_SENS_KEY,
@@ -1366,10 +1369,10 @@ class ArloCamera(ArloChildDevice):
         if cap in (LAST_CAPTURE_KEY, CAPTURED_TODAY_KEY, RECENT_ACTIVITY_KEY):
             return True
         if cap in (AUDIO_DETECTED_KEY,):
-            if self.model_id.startswith(
-                (
+            if self.model_id.startswith((
                     MODEL_ESSENTIAL,
                     MODEL_ESSENTIAL_INDOOR,
+                    MODEL_ESSENTIAL_XL,
                     MODEL_PRO_2,
                     MODEL_PRO_3,
                     MODEL_PRO_3_FLOODLIGHT,
@@ -1378,30 +1381,34 @@ class ArloCamera(ArloChildDevice):
                     MODEL_ULTRA,
                     MODEL_GO,
                     MODEL_BABY,
-                )
-            ):
+            )):
                 return True
             if self.device_type.startswith("arloq"):
                 return True
         if cap in (SIREN_STATE_KEY,):
-            if self.model_id.startswith(
-                (
+            if self.model_id.startswith((
                     MODEL_ESSENTIAL,
                     MODEL_ESSENTIAL_INDOOR,
+                    MODEL_ESSENTIAL_XL,
                     MODEL_PRO_3,
                     MODEL_PRO_3_FLOODLIGHT,
                     MODEL_PRO_4,
                     MODEL_PRO_5,
                     MODEL_ULTRA,
-                    MODEL_WIREFREE_VIDEO_DOORBELL,
-                )
-            ):
+                    MODEL_WIRED_VIDEO_DOORBELL2_HD,
+                    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+                    MODEL_ESSENTIAL_VIDEO_DOORBELL,
+            )):
                 return True
         if cap in (SPOTLIGHT_KEY,):
-            if self.model_id.startswith(
-                (MODEL_ESSENTIAL, MODEL_PRO_3, MODEL_PRO_4, MODEL_PRO_5,
-                 MODEL_ULTRA)
-            ):
+            if self.model_id.startswith((
+                    MODEL_ESSENTIAL,
+                    MODEL_ESSENTIAL_XL,
+                    MODEL_PRO_3,
+                    MODEL_PRO_4,
+                    MODEL_PRO_5,
+                    MODEL_ULTRA
+            )):
                 return True
         if cap in (TEMPERATURE_KEY, HUMIDITY_KEY, AIR_QUALITY_KEY):
             if self.model_id.startswith(MODEL_BABY):
@@ -1414,19 +1421,20 @@ class ArloCamera(ArloChildDevice):
                 return True
         if cap in (CONNECTION_KEY,):
             # These devices are their own base stations so don't re-add connection key.
-            if self.parent_id == self.device_id and self.model_id.startswith(
-                (
+            if self.parent_id == self.device_id and self.model_id.startswith((
                     MODEL_BABY,
                     MODEL_PRO_3_FLOODLIGHT,
                     MODEL_PRO_4,
                     MODEL_PRO_5,
                     MODEL_ESSENTIAL,
+                    MODEL_ESSENTIAL_XL,
                     MODEL_WIRED_VIDEO_DOORBELL,
-                    MODEL_WIREFREE_VIDEO_DOORBELL,
+                    MODEL_WIRED_VIDEO_DOORBELL2_HD,
+                    MODEL_WIRED_VIDEO_DOORBELL2_2K,
+                    MODEL_ESSENTIAL_VIDEO_DOORBELL,
                     MODEL_ESSENTIAL_INDOOR,
                     MODEL_GO,
-                )
-            ):
+            )):
                 return False
             if self.device_type in ("arloq", "arloqs"):
                 return False
